Macaca Python Client
====================

.. image:: https://img.shields.io/coveralls/macacajs/wd.py/master.svg
    :target: https://coveralls.io/github/macacajs/wd.py

.. image:: https://img.shields.io/travis/macacajs/wd.py/master.svg
    :target: https://travis-ci.org/macacajs/wd.py

.. image:: https://img.shields.io/pypi/v/wd.svg
    :target: https://pypi.python.org/pypi/wd

.. image:: https://img.shields.io/pypi/pyversions/wd.svg
    :target: https://pypi.python.org/pypi/wd/

.. image:: https://img.shields.io/pypi/dd/wd.svg
    :target: https://pypi.python.org/pypi/wd/

----

Python Webdriver Client
